@@ -3,7 +3,7 @@ from requests import HTTPError
 from rich.console import Console
 
 from odd_cli.client import Client
-from logger import logger
+from odd_cli.logger import logger
 
 app = typer.Typer(short_help="Manipulate OpenDataDiscovery platform's tokens")
 err_console = Console(stderr=True)
